==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPHealthCheckConfigFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HTTPHealthCheckConfigFluent<A extends HTTPHealthCheckConfigFluent<A>> extends Fluent<A>{
  public String getHost();
  public A withHost(String host);
  public Boolean hasHost();
  public A addToHttpHeaders(Integer index,HTTPHeader item);
  public A setToHttpHeaders(Integer index,HTTPHeader item);
  public A addToHttpHeaders(io.fabric8.istio.api.networking.v1alpha3.HTTPHeader... items);
  public A addAllToHttpHeaders(Collection<HTTPHeader> items);
  public A removeFromHttpHeaders(io.fabric8.istio.api.networking.v1alpha3.HTTPHeader... items);
  public A removeAllFromHttpHeaders(Collection<HTTPHeader> items);
  public A removeMatchingFromHttpHeaders(Predicate<HTTPHeaderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHttpHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPHeader> getHttpHeaders();
  public List<HTTPHeader> buildHttpHeaders();
  public HTTPHeader buildHttpHeader(Integer index);
  public HTTPHeader buildFirstHttpHeader();
  public HTTPHeader buildLastHttpHeader();
  public HTTPHeader buildMatchingHttpHeader(Predicate<HTTPHeaderBuilder> predicate);
  public Boolean hasMatchingHttpHeader(Predicate<HTTPHeaderBuilder> predicate);
  public A withHttpHeaders(List<HTTPHeader> httpHeaders);
  public A withHttpHeaders(io.fabric8.istio.api.networking.v1alpha3.HTTPHeader... httpHeaders);
  public Boolean hasHttpHeaders();
  public A addNewHttpHeader(String name,String value);
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> addNewHttpHeader();
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> addNewHttpHeaderLike(HTTPHeader item);
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> setNewHttpHeaderLike(Integer index,HTTPHeader item);
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> editHttpHeader(Integer index);
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> editFirstHttpHeader();
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> editLastHttpHeader();
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> editMatchingHttpHeader(Predicate<HTTPHeaderBuilder> predicate);
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public String getScheme();
  public A withScheme(String scheme);
  public Boolean hasScheme();
  public interface HttpHeadersNested<N> extends Nested<N>,HTTPHeaderFluent<HTTPHealthCheckConfigFluent.HttpHeadersNested<N>>{
    public N and();
    public N endHttpHeader();
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPHealthCheckConfigFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HTTPHealthCheckConfigFluent<A extends HTTPHealthCheckConfigFluent<A>> extends Fluent<A>{
  public String getHost();
  public A withHost(String host);
  public Boolean hasHost();
  public A addToHttpHeaders(int index,HTTPHeader item);
  public A setToHttpHeaders(int index,HTTPHeader item);
  public A addToHttpHeaders(io.fabric8.istio.api.networking.v1alpha3.HTTPHeader... items);
  public A addAllToHttpHeaders(Collection<HTTPHeader> items);
  public A removeFromHttpHeaders(io.fabric8.istio.api.networking.v1alpha3.HTTPHeader... items);
  public A removeAllFromHttpHeaders(Collection<HTTPHeader> items);
  public A removeMatchingFromHttpHeaders(Predicate<HTTPHeaderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHttpHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPHeader> getHttpHeaders();
  public List<HTTPHeader> buildHttpHeaders();
  public HTTPHeader buildHttpHeader(int index);
  public HTTPHeader buildFirstHttpHeader();
  public HTTPHeader buildLastHttpHeader();
  public HTTPHeader buildMatchingHttpHeader(Predicate<HTTPHeaderBuilder> predicate);
  public Boolean hasMatchingHttpHeader(Predicate<HTTPHeaderBuilder> predicate);
  public A withHttpHeaders(List<HTTPHeader> httpHeaders);
  public A withHttpHeaders(io.fabric8.istio.api.networking.v1alpha3.HTTPHeader... httpHeaders);
  public Boolean hasHttpHeaders();
  public A addNewHttpHeader(String name,String value);
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> addNewHttpHeader();
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> addNewHttpHeaderLike(HTTPHeader item);
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> setNewHttpHeaderLike(int index,HTTPHeader item);
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> editHttpHeader(int index);
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> editFirstHttpHeader();
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> editLastHttpHeader();
  public HTTPHealthCheckConfigFluent.HttpHeadersNested<A> editMatchingHttpHeader(Predicate<HTTPHeaderBuilder> predicate);
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public String getScheme();
  public A withScheme(String scheme);
  public Boolean hasScheme();
  public interface HttpHeadersNested<N> extends Nested<N>,HTTPHeaderFluent<HTTPHealthCheckConfigFluent.HttpHeadersNested<N>>{
    public N and();
    public N endHttpHeader();
    
  }
  
}
